#
# spec file for package git-repo
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-repo
Version:        2.21
Release:        bp155.1.5
Summary:        The Multiple Git Repository Tool
License:        Apache-2.0
URL:            https://gerrit.googlesource.com/git-repo
Source:         %{name}-%{version}.tar.xz
# SECTION tests
BuildRequires:  git
BuildRequires:  gpg2
BuildRequires:  python3-pytest
BuildRequires:  tree
# /SECTION
Requires:       python3-base
Requires:       git
BuildArch:      noarch

%description
Repo is a tool built on top of Git. Repo helps manage many Git repositories, does the uploads to
revision control systems, and automates parts of the development  workflow. Repo is not meant to
replace Git, only to make it easier to work with Git.

%prep
%setup -q
# fix shebang
sed -i -E "s|#!/usr/bin/env python.*|#!/usr/bin/python3|" repo run_tests
# remove unnecessary document
rm -f docs/windows.md

%build
# nothing to build

%install
install -Dm755 repo %{buildroot}%{_bindir}/repo

%check
%{buildroot}%{_bindir}/repo --help
git config --global user.email "abuild@local.localdomain"
./run_tests

%files
%doc README.md docs/*.md
%{_bindir}/repo
%license LICENSE

%changelog
* Fri Feb  4 2022 sebix+novell.com@sebix.at
- remove obsolete patch fix-python-readlink.patch
- Update to version 2.21:
  * project: mark gc.log as safe to discard when migrating .git/
  * init: add an option --enable-git-lfs-filter
  * init: make bad --repo-rev settings more clear
  * project: Ignore failure to remove the sample hooks
  * branches: Fix "not in" handling
  * project: store objects in project-objects directly
  * project: move --reference handling to project-objects
  * test_project: use os.readlink instead of Path.readlink
* Tue Jan 11 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- add fix-python-readlink.patch, fixing the project for python < 3.9.
* Tue Jan 11 2022 sebix+novell.com@sebix.at
- Update to version 2.20:
  * project: prune sample hooks
  * project: drop support for symlinking internal .git files
  * project: abort a bit earlier before migrating .git/
  * Revert "sync: dropped "NOTICE: --use-superproject is in beta ..." message."
  * project: stop symlinking info dir under .git/
  * project: stop symlinking description file under .git/
  * project: stop symlinking svn under .git/
  * project: clean up now unused code
  * sync: dropped "NOTICE: --use-superproject is in beta ..." message.
  * sync: With --mirror option, don't display no-use-superproject... message.
* Mon Jan 10 2022 sebix+novell.com@sebix.at
- Update to version 2.19:
  * project: migrate worktree .git/ dirs to symlinks
  * init, sync: fixed flake8 warnings.
  * superproject: Inherit --no-use-superproject with --mirror option.
  * sync: Handle tag ref in "upstream" field
  * project: init hooks in objdir only
  * sync: link the internal-fs-layout doc into checkouts
  * git-review: add config file
  * SUBMITTING_PATCHES: link to commit message style docs
  * man: refresh pages
  * help: fix grammar in help text
* Thu Jan  6 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 2.19.
